summaryrefslogtreecommitdiff
path: root/src/network/networkd-dhcp4.c
diff options
context:
space:
mode:
authorLennart Poettering <lennart@poettering.net>2015-08-27 01:14:20 +0200
committerLennart Poettering <lennart@poettering.net>2015-08-27 01:17:30 +0200
commit4b7b5abb785c03cb880e3a8a7a724d7de6e9cf3b (patch)
treeb962cbb2bcf29f10f4dd1c33e2e5ea209aa0205e /src/network/networkd-dhcp4.c
parent0339cd7707ac40c29d51ee6933d06bc87ed140a4 (diff)
dhcp: NTP servers should be requested by networkd but not implicitly by sd-dhcp
The library so far always requested the NTP servers. This might be unnecessary in some uses, hence let's move the request into networkd instead.
Diffstat (limited to 'src/network/networkd-dhcp4.c')
-rw-r--r--src/network/networkd-dhcp4.c6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/network/networkd-dhcp4.c b/src/network/networkd-dhcp4.c
index 7fce389fa2..ea1b18a0e5 100644
--- a/src/network/networkd-dhcp4.c
+++ b/src/network/networkd-dhcp4.c
@@ -624,7 +624,11 @@ int dhcp4_configure(Link *link) {
return r;
}
- /* Always acquire the timezone */
+ /* Always acquire the timezone and NTP*/
+ r = sd_dhcp_client_set_request_option(link->dhcp_client, DHCP_OPTION_NTP_SERVER);
+ if (r < 0)
+ return r;
+
r = sd_dhcp_client_set_request_option(link->dhcp_client, DHCP_OPTION_NEW_TZDB_TIMEZONE);
if (r < 0)
return r;